@@ -252,7 +252,8 @@ QStringList KCalPrefs::fullEmails()
 
     QStringList::Iterator it;
     KIdentityManagement::IdentityManager::ConstIterator it1;
-    for (it1 = idmanager->begin(); it1 != idmanager->end(); ++it1) {
+    KIdentityManagement::IdentityManager::ConstIterator end1(idmanager->end());
+    for (it1 = idmanager->begin(); it1 != end1; ++it1) {
         fullEmails << (*it1).fullEmailAddr();
     }
     // Add emails configured in korganizer
@@ -281,7 +282,7 @@ bool KCalPrefs::thatIsMe(const QString &_email)
 
     // in case email contains a full name, strip it out.
     // the below is the simpler but slower version of the following code:
-    // const QString email = KPIM::getEmailAddress( _email );
+    // const QString email = CalendarSupport::getEmailAddress( _email );
     const QByteArray tmp = _email.toUtf8();
     const char *cursor = tmp.constData();
     const char *end = tmp.data() + tmp.length();
@@ -294,8 +295,9 @@ bool KCalPrefs::thatIsMe(const QString &_email)
     }
 
     CalendarSupport::IdentityManager::ConstIterator it;
+    CalendarSupport::IdentityManager::ConstIterator endId(CalendarSupport::identityManager()->end());
     for (it = CalendarSupport::identityManager()->begin();
-            it != CalendarSupport::identityManager()->end(); ++it) {
+            it != endId; ++it) {
         if ((*it).matchesEmailAddress(email)) {
             return true;
         }
